@@ -1,5 +1,6 @@
 /***********************************************************************
  * SPDX-FileCopyrightText: 2020 Shubham <aryan100jangid@gmail.com>
+ * SPDX-FileCopyrightText: 2022 Harald Sitter <sitter@kde.org>
  *
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  ***********************************************************************/
@@ -7,6 +8,8 @@
 #ifndef TESTFILETREE_H
 #define TESTFILETREE_H
 
+#include <memory>
+
 #include "fileTree.h"
 
 #include <QTest>
@@ -17,7 +20,6 @@ class TestFileTree : public QObject
 
 public:
     TestFileTree();
-    ~TestFileTree() override;
 
 private:
     void testFileName();
@@ -25,7 +27,7 @@ private:
     void testFilePath();
 
 private:
-    File *fl;
+    std::unique_ptr<File> fl;
 };
 
 #endif
